Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(413)

Unified Diff: remoting/protocol/webrtc_video_stream.h

Issue 2767193007: [Chromoting] Send DesktopFrame::capturer_id() to client through WebrtcVideoStream (Closed)
Patch Set: crash in msan Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/frame_stats.cc ('k') | remoting/protocol/webrtc_video_stream.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/webrtc_video_stream.h
diff --git a/remoting/protocol/webrtc_video_stream.h b/remoting/protocol/webrtc_video_stream.h
index 6d1d1c67250ee704937d3843fb9d888ec1e5cb4a..376eec02025d520b12943797e651a8537d7d6120 100644
--- a/remoting/protocol/webrtc_video_stream.h
+++ b/remoting/protocol/webrtc_video_stream.h
@@ -52,8 +52,8 @@ class WebrtcVideoStream : public VideoStream,
void SetObserver(Observer* observer) override;
private:
- struct FrameTimestamps;
- struct EncodedFrameWithTimestamps;
+ struct FrameStats;
+ struct EncodedFrameWithStats;
// webrtc::DesktopCapturer::Callback interface.
void OnCaptureResult(webrtc::DesktopCapturer::Result result,
@@ -67,12 +67,12 @@ class WebrtcVideoStream : public VideoStream,
void CaptureNextFrame();
// Task running on the encoder thread to encode the |frame|.
- static EncodedFrameWithTimestamps EncodeFrame(
+ static EncodedFrameWithStats EncodeFrame(
WebrtcVideoEncoder* encoder,
std::unique_ptr<webrtc::DesktopFrame> frame,
WebrtcVideoEncoder::FrameParams params,
- std::unique_ptr<WebrtcVideoStream::FrameTimestamps> timestamps);
- void OnFrameEncoded(EncodedFrameWithTimestamps frame);
+ std::unique_ptr<WebrtcVideoStream::FrameStats> stats);
+ void OnFrameEncoded(EncodedFrameWithStats frame);
// Capturer used to capture the screen.
std::unique_ptr<webrtc::DesktopCapturer> capturer_;
@@ -90,8 +90,8 @@ class WebrtcVideoStream : public VideoStream,
HostVideoStatsDispatcher video_stats_dispatcher_;
- // Timestamps for the frame that's being captured.
- std::unique_ptr<FrameTimestamps> captured_frame_timestamps_;
+ // Stats of the frame that's being captured.
+ std::unique_ptr<FrameStats> captured_frame_stats_;
std::unique_ptr<WebrtcFrameScheduler> scheduler_;
« no previous file with comments | « remoting/protocol/frame_stats.cc ('k') | remoting/protocol/webrtc_video_stream.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698